@@ -54,7 +54,7 @@ def run(tests=(), reporter=None, stop_after=None):
 
 
 @attr.s(eq=False)
-class _StopAfterWrapper:
+class _StopAfterWrapper:  # noqa: PLW1641
     """
     Wrap a reporter to stop after a specified number of non-successes.
 
